@@ -1,8 +1,10 @@
+from django.apps import apps
 from django.urls import path
 
-from . import settings
 from . import views
 
+appConfig = apps.get_app_config('document_catalogue')
+
 app_name = 'document_catalogue'
 
 urlpatterns = [
@@ -11,9 +13,9 @@ urlpatterns = [
          name='catalogue_list'
     ),
     path('category/<slug:slug>/',
-         view=views.DocumentCategoryListView.as_view(),
+         view=views.CategoryDocumentListView.as_view(),
          name='category_list'
-    ),
+         ),
     path('detail/<int:pk>/',
          view=views.DocumentDetailView.as_view(),
          name='document_detail'
@@ -29,7 +31,7 @@ urlpatterns = [
     ),
 ]
 
-if settings.DOCUMENT_CATALOGUE_ENABLE_EDIT_URLS:
+if appConfig.settings.ENABLE_EDIT_URLS:
     urlpatterns += [
         path('edit/<int:pk>/',
              view=views.DocumentEditView.as_view(),
